@@ -69,8 +69,12 @@ MQDataReader$new <- function(.)
 #'  protein.descriptions      fasta.headers
 #'  potential.contaminant     contaminant
 #'  mass.deviations           mass.deviations..da.
+#'  basepeak.intensity        base.peak.intensity
 #' }
 #' 
+#' Note: you must find a regex which matches both versions, or explicitly add both terms if you are requesting only a subset
+#'       of columns!
+#' 
 #' Example of usage:
 #' \preformatted{
 #'   mq = MQDataReader$new()
@@ -196,6 +200,7 @@ MQDataReader$readMQ <- function(., file, filter="", type="pg", col_subset=NA, ad
   ## rename some columns since MQ 1.2 vs. 1.3 differ....
   cn[cn=="protease"] = "enzyme"
   cn[cn=="protein.descriptions"] = "fasta.headers"
+  cn[cn=="basepeak.intensity"] = "base.peak.intensity"
   ## MQ 1.0.13 and 1.1.x have 'mass.deviations', later versions have 'mass.deviations..da.'
   cn[cn=="mass.deviations"] = "mass.deviations..da."
   ## MQ 1.5 uses 'potential.contaminant' instead of 'contaminant'
